%global srcname alembic

Summary:          Database migration tool for SQLAlchemy
Name:             python-%{srcname}
Version:          1.9.3
Release:          8%{?dist}
License:          MIT
URL:              https://pypi.io/project/alembic
Source0:          %pypi_source %{srcname}
Patch3000:        0001-filter-out-DeprecationWarnings.patch

BuildArch:        noarch
BuildRequires:    help2man
BuildRequires:    python3-pytest

%description
Alembic is a new database migrations tool.


%package -n python3-alembic
Summary:          Database migration tool for SQLAlchemy

%description -n python3-alembic
Alembic is a new database migrations tool, written by the author of SQLAlchemy.
A migrations tool offers the following functionality:
* Can emit ALTER statements to a database in order to change the structure of
  tables and other constructs.
* Provides a system whereby "migration scripts" may be constructed; each script
  indicates a particular series of steps that can "upgrade" a target database
  to a new version, and optionally a series of steps that can "downgrade"
  similarly, doing the same steps in reverse.
* Allows the scripts to execute in some sequential manner.

Documentation and status of Alembic is at http://readthedocs.org/docs/alembic/


%prep
%autosetup -p1 -n %{srcname}-%{version}
rm -rvf docs/_static
sed -r -i 's/^([[:blank:]]*(black|zimports))\b/# &/' tox.ini

%generate_buildrequires
%pyproject_buildrequires -x tz


%build
%pyproject_wheel

mkdir -p  bin
echo 'python3 -c "import alembic.config; alembic.config.main()" $*' > bin/alembic
chmod 0755 bin/alembic
help2man --version-string %{version} --no-info -s 1 bin/alembic > alembic.1


%install
install -d -m 0755 %{buildroot}%{_mandir}/man1

%pyproject_install
%pyproject_save_files alembic

mv %{buildroot}/%{_bindir}/%{srcname} %{buildroot}/%{_bindir}/%{srcname}-3
ln -s %{srcname}-3 %{buildroot}/%{_bindir}/%{srcname}-%{python3_version}
install -m 0644 alembic.1 %{buildroot}%{_mandir}/man1/alembic-3.1
ln -s alembic-3.1 %{buildroot}%{_mandir}/man1/alembic-%{python3_version}.1

ln -s %{srcname}-%{python3_version} %{buildroot}/%{_bindir}/%{srcname}
ln -s alembic-%{python3_version}.1 %{buildroot}%{_mandir}/man1/alembic.1


%check
%pytest 


%files -n python3-%{srcname} -f %{pyproject_files}
%doc README.rst CHANGES docs
%{_bindir}/%{srcname}
%{_bindir}/%{srcname}-3
%{_bindir}/%{srcname}-%{python3_version}
%{_mandir}/man1/alembic.1*
%{_mandir}/man1/alembic-3.1*
%{_mandir}/man1/alembic-%{python3_version}.1*


%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.3-8
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Thu Aug 29 2024 Wang Guodong <gordonwwang@tencent.com> - 1.9.3-7
- Remove tox and use pytest instead

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.3-6
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.3-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.3-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.3-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 15 2023 rockerzhu <rockerzhu@tencent.com> - 1.9.3-1
- Initial build
